@@ -282,6 +282,13 @@ gb_button_normal_get_properties (GtkWidget * widget,
 	  else
 	    label_text = "";
 
+	  /* This is a bit of a hack. The label has the real translation
+	     properties, but we copy them to the button so everything works. */
+	  if (label) {
+	    glade_util_copy_translation_properties (label, "GtkLabel::label",
+						    widget, label_p);
+	  }
+
 	  /* When saving we only output the label if the icon isn't set,
 	     since if it is we will be saving as separate child widgets. */
 	  if (data->action != GB_SAVING || !icon)
@@ -493,14 +500,20 @@ gb_button_normal_set_properties	(GtkWidget * widget,
   icon_name = gb_widget_input_icon (data, icon_p);
   apply_icon = data->apply;
 
+  gb_button_normal_find_child_widgets (widget, &label_widget,
+				       &icon_widget);
+
+  /* This is a bit of a hack. The label has the real translation
+     properties, so we have to copy them back there. */
+  if (apply_label && label_widget)
+    glade_util_copy_translation_properties (widget, label_p,
+					    label_widget, "GtkLabel::label");
+
   /* If neither icon nor label is set, we don't touch the button as it may
      have other child widgets. */
   if (!apply_label && !apply_icon)
     return;
 
-  gb_button_normal_find_child_widgets (widget, &label_widget,
-				       &icon_widget);
-
   if (!apply_label)
     {
       if (label_widget)
@@ -550,6 +563,12 @@ gb_button_normal_set_properties	(GtkWidget * widget,
     {
       gb_button_normal_recreate_children (widget, data, label, icon_name);
 
+      gb_button_normal_find_child_widgets (widget, &label_widget,
+					   &icon_widget);
+      if (label_widget)
+	glade_util_copy_translation_properties (widget, label_p,
+						label_widget, "GtkLabel::label");
+
       goto out;
     }
 
@@ -601,11 +620,6 @@ gb_button_normal_write_source (GtkWidget * widget,
   GtkWidget *label_widget, *icon_widget;
   gchar *group_string = "", *group_string2 = "", *type, *stock_id;
   GType widget_type;
-  gboolean translatable, context;
-  gchar *comments;
-
-  glade_util_get_translation_properties (widget, label_p, &translatable,
-					 &comments, &context);
 
   widget_type = G_OBJECT_TYPE (widget);
   if (widget_type == GTK_TYPE_BUTTON)
@@ -646,7 +660,15 @@ gb_button_normal_write_source (GtkWidget * widget,
 
       if (label_widget && !icon_widget)
 	{
-	  gchar *label_text = glade_util_get_label_text (label_widget);
+	  gchar *label_text, *comments;
+	  gboolean translatable, context;
+
+	  label_text = glade_util_get_label_text (label_widget);
+	  glade_util_get_translation_properties (label_widget,
+						 "GtkLabel::label",
+						 &translatable, &comments,
+						 &context);
+
 	  source_add_translator_comments (data, translatable, comments);
 	  source_add (data, "  %s = gtk_%s_new_with_mnemonic (%s%s);\n",
 		      data->wname, type, group_string,
