@@ -29,7 +29,8 @@
  */
 static GbWidget gbwidget;
 
-static gchar *Policy = "HScrollbar|GtkRange::policy";
+static gchar *Policy = "HScrollbar|GtkRange::update_policy";
+static gchar *Inverted = "HScrollbar|GtkRange::inverted";
 
 static const gchar *Values[] =
 {
@@ -40,16 +41,6 @@ static const gchar *Values[] =
   "GtkHScrollbar::page",
   "GtkHScrollbar::page_size",
 };
-/* These are for backwards compatability, for pre Glade 0.5.2. */
-static const gchar *OldValues[] =
-{
-  "GtkHScrollbar::hvalue",
-  "GtkHScrollbar::hlower",
-  "GtkHScrollbar::hupper",
-  "GtkHScrollbar::hstep",
-  "GtkHScrollbar::hpage",
-  "GtkHScrollbar::hpage_size",
-};
 
 static const gchar *GbPolicyChoices[] =
 {"Continuous", "Discontinuous", "Delayed",
@@ -96,6 +87,7 @@ gb_hscrollbar_create_properties (GtkWidget * widget, GbWidgetCreateArgData * dat
   property_add_choice (Policy, _("Policy:"),
 		       _("The update policy of the scrollbar"),
 		       GbPolicyChoices);
+  property_add_bool (Inverted, _("Inverted:"), _("If the range values are inverted"));
   property_add_adjustment (Values, GB_ADJUST_DEFAULT_LABELS);
 }
 
@@ -111,11 +103,14 @@ gb_hscrollbar_get_properties (GtkWidget * widget, GbWidgetGetArgData * data)
   gint i;
   for (i = 0; i < sizeof (GbPolicyValues) / sizeof (GbPolicyValues[0]); i++)
     {
-      if (GbPolicyValues[i] == GTK_RANGE (widget)->policy)
+      if (GbPolicyValues[i] == GTK_RANGE (widget)->update_policy)
 	gb_widget_output_choice (data, Policy, i, GbPolicySymbols[i]);
     }
 
-  gb_widget_output_adjustment (data, Values, GTK_RANGE (widget)->adjustment);
+  gb_widget_output_bool (data, Inverted, GTK_RANGE (widget)->inverted);
+
+  gb_widget_output_adjustment (data, Values, GTK_RANGE (widget)->adjustment,
+			       "adjustment");
 }
 
 
@@ -129,6 +124,7 @@ gb_hscrollbar_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
 {
   gchar *policy;
   gint i;
+  gboolean inverted;
   GtkAdjustment *adj;
 
   policy = gb_widget_input_choice (data, Policy);
@@ -147,14 +143,16 @@ gb_hscrollbar_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
 	}
     }
 
-  /* If the new property names aren't used, try the old ones when loading. */
-  adj = GTK_RANGE (widget)->adjustment;
-  if (gb_widget_input_adjustment (data, Values, adj)
-      || (data->action == GB_LOADING
-	  && gb_widget_input_adjustment (data, OldValues, adj)))
+  inverted = gb_widget_input_bool (data, Inverted);
+  if (data->apply)
     {
-      /*gtk_signal_emit_by_name (GTK_OBJECT (adj), "value_changed");*/
-      gtk_range_slider_update (GTK_RANGE (widget));
+      gtk_range_set_inverted (GTK_RANGE (widget), inverted);
+    }
+
+  adj = GTK_RANGE (widget)->adjustment;
+  if (gb_widget_input_adjustment (data, Values, adj, "adjustment"))
+    {
+      gtk_signal_emit_by_name (GTK_OBJECT (adj), "changed");
     }
 }
 
@@ -196,17 +194,25 @@ gb_hscrollbar_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
 
   gb_widget_write_standard_source (widget, data);
 
-  if (GTK_RANGE (widget)->policy != GTK_UPDATE_CONTINUOUS)
+  if (GTK_RANGE (widget)->update_policy != GTK_UPDATE_CONTINUOUS)
     {
       for (i = 0; i < sizeof (GbPolicyValues) / sizeof (GbPolicyValues[0]); i
 	   ++)
 	{
-	  if (GbPolicyValues[i] == GTK_RANGE (widget)->policy)
+	  if (GbPolicyValues[i] == GTK_RANGE (widget)->update_policy)
 	    source_add (data,
 		    "  gtk_range_set_update_policy (GTK_RANGE (%s), %s);\n",
 			data->wname, GbPolicySymbols[i]);
 	}
     }
+
+  if (GTK_RANGE (widget)->inverted)
+    {
+      source_add (data,
+		  "  gtk_range_set_inverted (GTK_RANGE (%s), TRUE);\n",
+		  data->wname);
+
+    }
 }
 
 
@@ -220,7 +226,8 @@ GbWidget *
 gb_hscrollbar_init ()
 {
   /* Initialise the GTK type */
-  gtk_hscrollbar_get_type ();
+  volatile GtkType type;
+  type = gtk_hscrollbar_get_type ();
 
   /* Initialize the GbWidget structure */
   gb_widget_init_struct (&gbwidget);
