@@ -605,7 +605,9 @@ glade_atk_create_property_page	(GtkNotebook *notebook)
 {
   GtkWidget *page, *icon, *vbox, *table;
   GdkPixbuf *pixbuf;
-  AtkRelationType relationship;
+  /* Don't use AtkRelationType here since new values can be registered
+     dynamically, which can cause problems with optimizing compilers. */
+  int relationship;
 
   page = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (page),
