@@ -45,10 +45,10 @@ static void glade_keys_dialog_init         (GladeKeysDialog       *dialog);
 static GtkDialogClass *parent_class = NULL;
 
 
-guint
+GType
 glade_keys_dialog_get_type (void)
 {
-  static guint glade_keys_dialog_type = 0;
+  static GType glade_keys_dialog_type = 0;
 
   if (!glade_keys_dialog_type)
     {
