@@ -53,6 +53,7 @@ static gchar *SkipTaskbar = "GnomeDialog|GtkWindow::skip_taskbar_hint";
 static gchar *SkipPager = "GnomeDialog|GtkWindow::skip_pager_hint";
 static gchar *Decorated = "GnomeDialog|GtkWindow::decorated";
 static gchar *Gravity = "GnomeDialog|GtkWindow::gravity";
+static gchar *Urgency = "GnomeDialog|GtkWindow::urgency_hint";
 
 static gchar *AutoClose = "GnomeDialog::auto_close";
 static gchar *HideOnClose = "GnomeDialog::hide_on_close";
@@ -148,7 +149,7 @@ gb_gnome_dialog_create_properties (GtkWidget * widget, GbWidgetCreateArgData * d
 					IconName, FocusOnMap,
 					Resizable, DestroyWithParent, Icon,
 					Role, TypeHint, SkipTaskbar,
-					SkipPager, Decorated, Gravity);
+					SkipPager, Decorated, Gravity, Urgency);
   property_add_bool (AutoClose, _("Auto Close:"),
 		     _("If the dialog closes when any button is clicked"));
   property_add_bool (HideOnClose, _("Hide on Close:"),
@@ -171,7 +172,7 @@ gb_gnome_dialog_get_properties (GtkWidget *widget, GbWidgetGetArgData * data)
 				     IconName, FocusOnMap,
 				     Resizable, DestroyWithParent, Icon,
 				     Role, TypeHint, SkipTaskbar,
-				     SkipPager, Decorated, Gravity);
+				     SkipPager, Decorated, Gravity, Urgency);
 
   gb_widget_output_bool (data, AutoClose, GNOME_DIALOG (widget)->click_closes);
   gb_widget_output_bool (data, HideOnClose, GNOME_DIALOG (widget)->just_hide);
@@ -195,7 +196,7 @@ gb_gnome_dialog_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
 				     IconName, FocusOnMap,
 				     Resizable, DestroyWithParent, Icon,
 				     Role, TypeHint, SkipTaskbar,
-				     SkipPager, Decorated, Gravity);
+				     SkipPager, Decorated, Gravity, Urgency);
 
   auto_close = gb_widget_input_bool (data, AutoClose);
   if (data->apply)
@@ -260,7 +261,7 @@ gb_gnome_dialog_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data
 				   IconName, FocusOnMap,
 				   Resizable, DestroyWithParent, Icon,
 				   Role, TypeHint, SkipTaskbar,
-				   SkipPager, Decorated, Gravity);
+				   SkipPager, Decorated, Gravity, Urgency);
 
   if (GNOME_DIALOG (widget)->click_closes)
     {
